@@ -8,6 +8,7 @@ from django_tables2 import RequestConfig
 from rest_framework import renderers
 
 from nautobot.core.forms import SearchForm
+from nautobot.core.utilities import check_filter_for_display
 from nautobot.extras.models.change_logging import ChangeLoggedModel, ObjectChange
 from nautobot.extras.utils import get_base_template
 from nautobot.utilities.forms import (
@@ -165,6 +166,7 @@ class NautobotHTMLRenderer(renderers.BrowsableAPIRenderer):
                 filter_params = self.get_filter_params(view, request)
                 if view.filterset_class is not None:
                     filterset = view.filterset_class(filter_params, view.queryset)
+                    filterset_filters = filterset.get_filters()
                     view.queryset = filterset.qs
                     if not filterset.is_valid():
                         messages.error(
@@ -174,7 +176,7 @@ class NautobotHTMLRenderer(renderers.BrowsableAPIRenderer):
                         view.queryset = view.queryset.none()
 
                     display_filter_params = [
-                        [field_name, values if isinstance(values, (list, tuple)) else [values]]
+                        check_filter_for_display(filterset_filters, field_name, values)
                         for field_name, values in filter_params.items()
                     ]
                     if view.filterset_form_class is not None:
