@@ -62,6 +62,13 @@ class CustomFieldTypeChoices(ChoiceSet):
         (TYPE_JSON, "JSON"),
     )
 
+    REGEX_TYPES = (
+        TYPE_TEXT,
+        TYPE_URL,
+        TYPE_SELECT,
+        TYPE_MULTISELECT,
+    )
+
 
 #
 # CustomLinks
@@ -89,6 +96,23 @@ class CustomLinkButtonClassChoices(ChoiceSet):
     )
 
 
+#
+# Dynamic Groups
+#
+
+
+class DynamicGroupOperatorChoices(ChoiceSet):
+    OPERATOR_UNION = "union"
+    OPERATOR_INTERSECTION = "intersection"
+    OPERATOR_DIFFERENCE = "difference"
+
+    CHOICES = (
+        (OPERATOR_UNION, "Include (OR)"),
+        (OPERATOR_INTERSECTION, "Restrict (AND)"),
+        (OPERATOR_DIFFERENCE, "Exclude (NOT)"),
+    )
+
+
 #
 # Jobs
 #
@@ -114,6 +138,7 @@ class JobExecutionType(ChoiceSet):
     TYPE_HOURLY = "hourly"
     TYPE_DAILY = "daily"
     TYPE_WEEKLY = "weekly"
+    TYPE_CUSTOM = "custom"
 
     CHOICES = (
         (TYPE_IMMEDIATELY, "Once immediately"),
@@ -121,6 +146,7 @@ class JobExecutionType(ChoiceSet):
         (TYPE_HOURLY, "Recurring hourly"),
         (TYPE_DAILY, "Recurring daily"),
         (TYPE_WEEKLY, "Recurring weekly"),
+        (TYPE_CUSTOM, "Recurring custom"),
     )
 
     SCHEDULE_CHOICES = (
@@ -128,12 +154,14 @@ class JobExecutionType(ChoiceSet):
         TYPE_HOURLY,
         TYPE_DAILY,
         TYPE_WEEKLY,
+        TYPE_CUSTOM,
     )
 
     RECURRING_CHOICES = (
         TYPE_HOURLY,
         TYPE_DAILY,
         TYPE_WEEKLY,
+        TYPE_CUSTOM,
     )
 
     CELERY_INTERVAL_MAP = {
@@ -225,11 +253,40 @@ class ObjectChangeActionChoices(ChoiceSet):
     }
 
 
+class ObjectChangeEventContextChoices(ChoiceSet):
+
+    CONTEXT_WEB = "web"
+    CONTEXT_JOB = "job"
+    CONTEXT_JOB_HOOK = "job-hook"
+    CONTEXT_ORM = "orm"
+    CONTEXT_UNKNOWN = "unknown"
+
+    CHOICES = (
+        (CONTEXT_WEB, "Web"),
+        (CONTEXT_JOB, "Job"),
+        (CONTEXT_JOB_HOOK, "Job hook"),
+        (CONTEXT_ORM, "ORM"),
+        (CONTEXT_UNKNOWN, "Unknown"),
+    )
+
+
 #
 # Relationships
 #
 
 
+class RelationshipRequiredSideChoices(ChoiceSet):
+    NEITHER_SIDE_REQUIRED = ""
+    SOURCE_SIDE_REQUIRED = "source"
+    DESTINATION_SIDE_REQUIRED = "destination"
+
+    CHOICES = (
+        (NEITHER_SIDE_REQUIRED, "Neither side required"),
+        (SOURCE_SIDE_REQUIRED, "Source objects MUST implement this relationship"),
+        (DESTINATION_SIDE_REQUIRED, "Destination objects MUST implement this relationship"),
+    )
+
+
 class RelationshipSideChoices(ChoiceSet):
 
     SIDE_SOURCE = "source"
