@@ -114,29 +114,30 @@ class TestVarbinaryIPField(TestCase):
 
 class TestAggregate(TestCase):
     def test_get_utilization(self):
-        rir = RIR.objects.create(name="RIR 1", slug="rir-1")
-        aggregate = Aggregate(prefix=netaddr.IPNetwork("10.0.0.0/8"), rir=rir)
+        aggregate = Aggregate(prefix=netaddr.IPNetwork("22.0.0.0/8"), rir=RIR.objects.first())
         aggregate.save()
 
         # 25% utilization
         Prefix.objects.bulk_create(
             (
-                Prefix(prefix=netaddr.IPNetwork("10.0.0.0/12")),
-                Prefix(prefix=netaddr.IPNetwork("10.16.0.0/12")),
-                Prefix(prefix=netaddr.IPNetwork("10.32.0.0/12")),
-                Prefix(prefix=netaddr.IPNetwork("10.48.0.0/12")),
+                Prefix(prefix=netaddr.IPNetwork("22.0.0.0/12")),
+                Prefix(prefix=netaddr.IPNetwork("22.16.0.0/12")),
+                Prefix(prefix=netaddr.IPNetwork("22.32.0.0/12")),
+                Prefix(prefix=netaddr.IPNetwork("22.48.0.0/12")),
             )
         )
         self.assertEqual(aggregate.get_utilization(), (4194304, 16777216))
 
         # 50% utilization
-        Prefix.objects.bulk_create((Prefix(prefix=netaddr.IPNetwork("10.64.0.0/10")),))
+        Prefix.objects.bulk_create((Prefix(prefix=netaddr.IPNetwork("22.64.0.0/10")),))
         self.assertEqual(aggregate.get_utilization(), (8388608, 16777216))
 
         # 100% utilization
-        Prefix.objects.bulk_create((Prefix(prefix=netaddr.IPNetwork("10.128.0.0/9")),))
+        Prefix.objects.bulk_create((Prefix(prefix=netaddr.IPNetwork("22.128.0.0/9")),))
         self.assertEqual(aggregate.get_utilization(), (16777216, 16777216))
 
+        # TODO: equivalent IPv6 tests for thoroughness?
+
 
 class TestPrefix(TestCase):
     def setUp(self):
@@ -144,20 +145,20 @@ class TestPrefix(TestCase):
         self.statuses = Status.objects.get_for_model(Prefix)
 
     def test_prefix_validation(self):
-        site = Site.objects.create(name="Site 1")
-        location_type = LocationType.objects.create(name="Location Type 1")
-        location = Location.objects.create(name="Location 1", location_type=location_type, site=site)
+        location_type = LocationType.objects.get(name="Room")
+        location = Location.objects.filter(location_type=location_type).first()
         prefix = Prefix(prefix=netaddr.IPNetwork("192.0.2.0/24"), location=location)
+        prefix.status = self.statuses.get(slug="active")
         with self.assertRaises(ValidationError) as cm:
             prefix.validated_save()
-        self.assertIn('Prefixes may not associate to locations of type "Location Type 1"', str(cm.exception))
+        self.assertIn(f'Prefixes may not associate to locations of type "{location_type.name}"', str(cm.exception))
 
         location_type.content_types.add(ContentType.objects.get_for_model(Prefix))
-        site_2 = Site.objects.create(name="Site 2")
+        site_2 = Site.objects.exclude(pk=location.base_site.pk).last()
         prefix.site = site_2
         with self.assertRaises(ValidationError) as cm:
             prefix.validated_save()
-        self.assertIn('Location "Location 1" does not belong to site "Site 2"', str(cm.exception))
+        self.assertIn(f'Location "{location.name}" does not belong to site "{site_2.name}"', str(cm.exception))
 
     def test_get_duplicates(self):
         prefixes = (
@@ -170,11 +171,7 @@ class TestPrefix(TestCase):
         self.assertSetEqual(set(duplicate_prefix_pks), {prefixes[1].pk, prefixes[2].pk})
 
     def test_get_child_prefixes(self):
-        vrfs = (
-            VRF.objects.create(name="VRF 1"),
-            VRF.objects.create(name="VRF 2"),
-            VRF.objects.create(name="VRF 3"),
-        )
+        vrfs = VRF.objects.all()[:3]
         prefixes = (
             Prefix.objects.create(prefix=netaddr.IPNetwork("10.0.0.0/16"), status=Prefix.STATUS_CONTAINER),
             Prefix.objects.create(prefix=netaddr.IPNetwork("10.0.0.0/24"), vrf=None),
@@ -198,11 +195,7 @@ class TestPrefix(TestCase):
         self.assertSetEqual(child_prefix_pks, {prefixes[2].pk})
 
     def test_get_child_ips(self):
-        vrfs = (
-            VRF.objects.create(name="VRF 1"),
-            VRF.objects.create(name="VRF 2"),
-            VRF.objects.create(name="VRF 3"),
-        )
+        vrfs = VRF.objects.all()[:3]
         parent_prefix = Prefix.objects.create(prefix=netaddr.IPNetwork("10.0.0.0/16"), status=Prefix.STATUS_CONTAINER)
         ips = (
             IPAddress.objects.create(address=netaddr.IPNetwork("10.0.0.1/24"), vrf=None),
@@ -376,13 +369,13 @@ class TestPrefix(TestCase):
         self.assertRaises(ValidationError, duplicate_prefix.clean)
 
     def test_duplicate_vrf(self):
-        vrf = VRF.objects.create(name="Test", rd="1:1", enforce_unique=False)
+        vrf = VRF.objects.filter(enforce_unique=False).first()
         Prefix.objects.create(vrf=vrf, prefix=netaddr.IPNetwork("192.0.2.0/24"))
         duplicate_prefix = Prefix(vrf=vrf, prefix=netaddr.IPNetwork("192.0.2.0/24"))
         self.assertIsNone(duplicate_prefix.clean())
 
     def test_duplicate_vrf_unique(self):
-        vrf = VRF.objects.create(name="Test", rd="1:1", enforce_unique=True)
+        vrf = VRF.objects.filter(enforce_unique=True).first()
         Prefix.objects.create(vrf=vrf, prefix=netaddr.IPNetwork("192.0.2.0/24"))
         duplicate_prefix = Prefix(vrf=vrf, prefix=netaddr.IPNetwork("192.0.2.0/24"))
         self.assertRaises(ValidationError, duplicate_prefix.clean)
@@ -416,13 +409,13 @@ class TestIPAddress(TestCase):
         self.assertRaises(ValidationError, duplicate_ip.clean)
 
     def test_duplicate_vrf(self):
-        vrf = VRF.objects.create(name="Test", rd="1:1", enforce_unique=False)
+        vrf = VRF.objects.filter(enforce_unique=False).first()
         IPAddress.objects.create(vrf=vrf, address=netaddr.IPNetwork("192.0.2.1/24"))
         duplicate_ip = IPAddress(vrf=vrf, address=netaddr.IPNetwork("192.0.2.1/24"))
         self.assertIsNone(duplicate_ip.clean())
 
     def test_duplicate_vrf_unique(self):
-        vrf = VRF.objects.create(name="Test", rd="1:1", enforce_unique=True)
+        vrf = VRF.objects.filter(enforce_unique=True).first()
         IPAddress.objects.create(vrf=vrf, address=netaddr.IPNetwork("192.0.2.1/24"))
         duplicate_ip = IPAddress(vrf=vrf, address=netaddr.IPNetwork("192.0.2.1/24"))
         self.assertRaises(ValidationError, duplicate_ip.clean)
@@ -482,7 +475,7 @@ class TestIPAddress(TestCase):
 
     @override_settings(ENFORCE_GLOBAL_UNIQUE=True)
     def test_not_null_assigned_object_type_and_null_assigned_object_id(self):
-        site = Site.objects.create(name="Test Site 1", slug="test-site-1")
+        site = Site.objects.first()
         manufacturer = Manufacturer.objects.create(name="Test Manufacturer 1", slug="test-manufacturer-1")
         devicetype = DeviceType.objects.create(
             manufacturer=manufacturer,
@@ -518,6 +511,7 @@ class TestIPAddress(TestCase):
         self.assertIsNone(ipaddress_2.clean())
 
     def test_create_ip_address_without_slaac_status(self):
+        IPAddress.objects.filter(status__slug=IPAddressStatusChoices.STATUS_SLAAC).delete()
         Status.objects.get(slug=IPAddressStatusChoices.STATUS_SLAAC).delete()
         IPAddress.objects.create(address="1.1.1.1/32")
         self.assertTrue(IPAddress.objects.filter(address="1.1.1.1/32").exists())
@@ -525,20 +519,19 @@ class TestIPAddress(TestCase):
 
 class TestVLANGroup(TestCase):
     def test_vlan_group_validation(self):
-        site = Site.objects.create(name="Site 1")
-        location_type = LocationType.objects.create(name="Location Type 1")
-        location = Location.objects.create(name="Location 1", location_type=location_type, site=site)
+        location_type = LocationType.objects.get(name="Elevator")
+        location = Location.objects.filter(location_type=location_type).first()
         group = VLANGroup(name="Group 1", location=location)
         with self.assertRaises(ValidationError) as cm:
             group.validated_save()
-        self.assertIn('VLAN groups may not associate to locations of type "Location Type 1"', str(cm.exception))
+        self.assertIn(f'VLAN groups may not associate to locations of type "{location_type.name}"', str(cm.exception))
 
         location_type.content_types.add(ContentType.objects.get_for_model(VLANGroup))
-        site_2 = Site.objects.create(name="Site 2")
+        site_2 = Site.objects.exclude(pk=location.base_site.pk).last()
         group.site = site_2
         with self.assertRaises(ValidationError) as cm:
             group.validated_save()
-        self.assertIn('Location "Location 1" does not belong to site "Site 2"', str(cm.exception))
+        self.assertIn(f'Location "{location.name}" does not belong to site "{site_2.name}"', str(cm.exception))
 
     def test_get_next_available_vid(self):
 
@@ -559,34 +552,37 @@ class TestVLANGroup(TestCase):
 
 class VLANTestCase(TestCase):
     def test_vlan_validation(self):
-        site = Site.objects.create(name="Site 1")
-        location_type = LocationType.objects.create(name="Location Type 1")
-        location = Location.objects.create(name="Location 1", location_type=location_type, site=site)
+        location_type = LocationType.objects.get(name="Root")
+        location_type.content_types.set([])
+        location_type.validated_save()
+        location = Location.objects.filter(location_type=location_type).first()
         vlan = VLAN(name="Group 1", vid=1, location=location)
+        vlan.status = Status.objects.get_for_model(VLAN).get(slug="active")
         with self.assertRaises(ValidationError) as cm:
             vlan.validated_save()
-        self.assertIn('VLANs may not associate to locations of type "Location Type 1"', str(cm.exception))
+        self.assertIn(f'VLANs may not associate to locations of type "{location_type.name}"', str(cm.exception))
 
         location_type.content_types.add(ContentType.objects.get_for_model(VLAN))
-        site_2 = Site.objects.create(name="Site 2")
+        site_2 = Site.objects.exclude(pk=location.site.pk).first()
         vlan.site = site_2
         with self.assertRaises(ValidationError) as cm:
             vlan.validated_save()
-        self.assertIn('Location "Location 1" does not belong to site "Site 2"', str(cm.exception))
+        self.assertIn(f'Location "{location.name}" does not belong to site "{site_2.name}"', str(cm.exception))
 
-        vlan.site = site
+        vlan.site = location.site
         group = VLANGroup.objects.create(name="Group 1", site=site_2)
         vlan.group = group
         with self.assertRaises(ValidationError) as cm:
             vlan.validated_save()
-        self.assertIn("VLAN group must belong to the assigned site (Site 1)", str(cm.exception))
+        self.assertIn(f"VLAN group must belong to the assigned site ({location.site.name})", str(cm.exception))
 
-        group.site = site
-        location_2 = Location.objects.create(name="Location 2", location_type=location_type, site=site)
+        group.site = location.site
+        location_2 = Location.objects.create(name="Location 2", location_type=location_type, site=location.site)
         group.location = location_2
         group.save()
         with self.assertRaises(ValidationError) as cm:
             vlan.validated_save()
         self.assertIn(
-            'The assigned group belongs to a location that does not include location "Location 1"', str(cm.exception)
+            f'The assigned group belongs to a location that does not include location "{location.name}"',
+            str(cm.exception),
         )
