@@ -50,13 +50,14 @@ function colorPickerClassCopy(data, container) {
 */
 
 // Static choice selection
-function initializeStaticChoiceSelection(context){
+function initializeStaticChoiceSelection(context, dropdownParent=null){
     this_context = $(context);
     this_context.find('.nautobot-select2-static').select2({
         allowClear: true,
         placeholder: "---------",
         theme: "bootstrap",
-        width: "off"
+        width: "off",
+        dropdownParent: dropdownParent
     });
 }
 
@@ -139,7 +140,7 @@ function initializeBulkEditNullification(context){
 }
 
 // Color Picker
-function initializeColorPicker(context){
+function initializeColorPicker(context, dropdownParent=null){
     this_context = $(context);
     this_context.find('.nautobot-select2-color-picker').select2({
         allowClear: true,
@@ -147,18 +148,20 @@ function initializeColorPicker(context){
         theme: "bootstrap",
         templateResult: colorPickerClassCopy,
         templateSelection: colorPickerClassCopy,
-        width: "off"
+        width: "off",
+        dropdownParent: dropdownParent
     });
 }
 
 // Dynamic Choice Selection
-function initializeDynamicChoiceSelection(context){
+function initializeDynamicChoiceSelection(context, dropdownParent=null){
     this_context = $(context);
     this_context.find('.nautobot-select2-api').select2({
         allowClear: true,
         placeholder: "---------",
         theme: "bootstrap",
         width: "off",
+        dropdownParent: dropdownParent,
         ajax: {
             delay: 500,
 
@@ -328,7 +331,7 @@ function initializeDateTimePicker(context){
     });
 }
 
-function initializeTags(context){
+function initializeTags(context, dropdownParent=null){
     this_context = $(context);
     this_tag_field = this_context.find('#id_tags.tagfield')
     var tags = this_tag_field;
@@ -354,6 +357,7 @@ function initializeTags(context){
         placeholder: "Tags",
         theme: "bootstrap",
         width: "off",
+        dropdownParent: dropdownParent,
         ajax: {
             delay: 250,
             url: nautobot_api_path + "extras/tags/",
@@ -439,7 +443,7 @@ function initializeVLANModeSelection(context){
     }
 }
 
-function initializeMultiValueChar(context){
+function initializeMultiValueChar(context, dropdownParent=null){
     this_context = $(context);
     this_context.find('.nautobot-select2-multi-value-char').select2({
         allowClear: true,
@@ -447,6 +451,7 @@ function initializeMultiValueChar(context){
         theme: "bootstrap",
         placeholder: "---------",
         multiple: true,
+        dropdownParent: dropdownParent,
         width: "off",
         "language": {
             "noResults": function(){
@@ -613,6 +618,15 @@ function initializeInputs(context) {
     initializeDynamicFilterForm(this_context)
     initializeSelectAllForm(this_context)
     initializeMultiValueChar(this_context)
+
+    $(this_context).find(".modal").each(function() {
+        this_modal = $(this)
+        initializeStaticChoiceSelection(this_modal, this_modal)
+        initializeColorPicker(this_modal, this_modal)
+        initializeDynamicChoiceSelection(this_modal, this_modal)
+        initializeTags(this_modal, this_modal)
+        initializeMultiValueChar(this_modal, this_modal)
+    })
 }
 
 function jsify_form(context) {
